==> mule-datasense-4.1.6-sources.jar: org/mule/datasense/impl/phases/annotators/DynamicSourceAnnotator.java <==
package org.mule.datasense.impl.phases.annotators;

import org.mule.datasense.api.metadataprovider.DataSenseMetadataProvider;
import org.mule.datasense.impl.model.annotations.ComponentLocationAnnotation;
import org.mule.datasense.impl.model.annotations.metadata.SourceModelAnnotation;
import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.reporting.NotificationMessages;
import org.mule.datasense.impl.phases.typing.AnnotatingMuleAstVisitorContext;
import org.mule.runtime.api.i18n.I18nMessageFactory;
import org.mule.runtime.api.meta.model.source.SourceModel;
import org.mule.runtime.api.metadata.descriptor.ComponentMetadataDescriptor;
import org.mule.runtime.api.metadata.resolving.MetadataResult;

public class DynamicSourceAnnotator extends BaseDynamicAnnotator<SourceModel> {

  protected MetadataResult<ComponentMetadataDescriptor<SourceModel>> resolveMetadata(
                                                                                     MessageProcessorNode messageProcessorNode,
                                                                                     DataSenseMetadataProvider dataSenseMetadataProvider,
                                                                                     ComponentLocationAnnotation componentLocationAnnotation,
                                                                                     AnnotatingMuleAstVisitorContext annotatingMuleAstVisitorContext) {

    final MetadataResult<ComponentMetadataDescriptor<SourceModel>> sourceMetadata =
        dataSenseMetadataProvider.getSourceMetadata(componentLocationAnnotation.getLocation());
    if (sourceMetadata != null) {
      final ComponentMetadataDescriptor<SourceModel> sourceModelComponentMetadataDescriptor = sourceMetadata.get();
      if (sourceModelComponentMetadataDescriptor != null) {
        final SourceModel sourceModel = sourceModelComponentMetadataDescriptor.getModel();
        if (sourceModel != null) {
          messageProcessorNode.annotate(new SourceModelAnnotation(sourceModel));
        }
      }
    } else {
      annotatingMuleAstVisitorContext.getAstNotification()
          .reportError(messageProcessorNode.getAstNodeLocation(), I18nMessageFactory
              .createStaticMessage(NotificationMessages.MSG_FAILED_TO_OBTAIN_METADATA,
                                   "source metadata for component_path: " + componentLocationAnnotation.getLocation()));

    }
    return sourceMetadata;
  }
}

==> mule-datasense-4.6.25-20251025.124806-2-sources.jar: org/mule/datasense/impl/phases/annotators/DynamicSourceAnnotator.java <==
package org.mule.datasense.impl.phases.annotators;

import org.mule.datasense.api.metadataprovider.DataSenseMetadataProvider;
import org.mule.datasense.impl.model.annotations.ComponentLocationAnnotation;
import org.mule.datasense.impl.model.annotations.metadata.SourceModelAnnotation;
import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.reporting.NotificationMessages;
import org.mule.datasense.impl.phases.typing.AnnotatingMuleAstVisitorContext;
import org.mule.runtime.api.i18n.I18nMessageFactory;
import org.mule.runtime.api.meta.model.source.SourceModel;
import org.mule.runtime.api.metadata.resolving.MetadataResult;

public class DynamicSourceAnnotator extends BaseDynamicAnnotator<SourceModel> {

  protected MetadataResult<SourceModel> resolveMetadata(MessageProcessorNode messageProcessorNode,
                                                        DataSenseMetadataProvider dataSenseMetadataProvider,
                                                        ComponentLocationAnnotation componentLocationAnnotation,
                                                        AnnotatingMuleAstVisitorContext annotatingMuleAstVisitorContext) {

    final MetadataResult<SourceModel> sourceMetadata =
        dataSenseMetadataProvider.getSourceMetadata(messageProcessorNode.getComponentModel());
    if (sourceMetadata != null) {
      if (sourceMetadata.isSuccess()) {
        final SourceModel sourceModel = sourceMetadata.get();
        messageProcessorNode.annotate(new SourceModelAnnotation(sourceModel));
      }
    } else {
      annotatingMuleAstVisitorContext.getAstNotification()
          .reportError(messageProcessorNode.getAstNodeLocation(), I18nMessageFactory
              .createStaticMessage(NotificationMessages.MSG_FAILED_TO_OBTAIN_METADATA,
                                   "source metadata for component_path: " + componentLocationAnnotation.getLocation()));

    }
    return sourceMetadata;
  }
}
